package com.qmth.cqb.paper.service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

import com.qmth.cqb.paper.model.Paper;
import com.qmth.cqb.question.model.ImportPaperSearchCondition;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

@Service
public class ImportPaperService {
	

    /**
     * 一般返回类型统一为NormalResponse对象
     * NormalResponse(String httpStatus, String Message)
     * 分页集合返回类型为PagingAndSortingResponse
     * PagingAndSortingResponse(int curPage, int pageSize, int totalPages, long totalElements, List dataList)
     * 一般集合返回类型为List
     */

    @Autowired
    com.qmth.cqb.paper.dao.PaperRepo paperRepo;


    /**
     * 查询所有已导入试卷
     * @param searchCondition
     * @param curPage
     * @param pageSize
     * @return
     */
    public PagingAndSortingResponse<Paper> findAll(ImportPaperSearchCondition searchCondition,int curPage,int pageSize){
    	Paper importPaper = new Paper();
    	BeanUtils.copyProperties(searchCondition,importPaper);
    	ExampleMatcher matcher = ExampleMatcher.matching().withMatcher("paperName", startsWith());
        Page<Paper> importPaperList = paperRepo.findAll(Example.of(importPaper,matcher),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<Paper>(importPaperList.getNumber(),importPaperList.getSize(),
                importPaperList.getTotalPages(),importPaperList.getTotalElements(),importPaperList.getContent());
    }

    /**
     * 按ID查询导入试卷
     * @param paperId
     * @return
     */
    public Paper findById(String paperId){
        return paperRepo.findOne(paperId);
    }

    /**
     * 保存试卷
     * @param importPaper
     * @return
     */
    public Paper saveImportPaper(Paper importPaper){
    	Paper tempPaper = paperRepo.save(importPaper);
        return tempPaper;
    }

    /**
     * 删除导入试卷
     * @param paperId
     * @return
     */
    public void deleteImportPaper(String paperId){
    	paperRepo.delete(paperId);
    }

}
