package com.qmth.cqb.paper.web;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.cqb.paper.model.Paper;
import com.qmth.cqb.paper.service.ImportPaperService;
import com.qmth.cqb.question.model.ImportPaperSearchCondition;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

/**
 * Created by songyue on 16/12/28.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class ImportPaperController {
	
	@Autowired
	ImportPaperService importPaperService;
    /**
     * 获取导入试卷
     * @param importPaper_id
     * @return
     */
    @GetMapping(value = "/importPaper/{importPaper_id}")
    public Paper getPaperById(@PathVariable String importPaper_id){
        return importPaperService.findById(importPaper_id);
    }
    
    /**
     * 获取导入试卷的所有试题
     * @param importPaper_id
     * @return
     */
//    @GetMapping(value = "/importPaper/question/{importPaper_id}")
//    public List<Question> getQuesPaperById(@PathVariable String importPaper_id){
//    	return importPaperService.findById(importPaper_id).getQuestionList();
//    }


    /**
     * 获取全部导入试卷
     * @return
     */
    @GetMapping(value = "/importPaper/all/{curPage}/{paseSize}")
    public PagingAndSortingResponse<Paper> getAllPaper(@ModelAttribute ImportPaperSearchCondition searchCondition, @PathVariable int curPage, @PathVariable int pageSize){
      PagingAndSortingResponse<Paper> psr = importPaperService.findAll(searchCondition, curPage, pageSize);
      return psr;
    }

    /**
     * 更新导入试卷信息
     * @param 
     * @return
     */
    @PutMapping(value = "/importPaper")
    public ResponseEntity updatePaper(@ModelAttribute Paper paper){
    	Paper paper2 = importPaperService.saveImportPaper(paper);
    	ResponseEntity rse = new ResponseEntity(paper2,HttpStatus.OK);
    	return rse;
    	
    }

    /**
     * 新增导入试卷
     * @param paper
     * @return
     */
    @PostMapping(value = "/importPaper")
    public ResponseEntity addPaper(@ModelAttribute Paper paper){
    	Paper paper2 = importPaperService.saveImportPaper(paper);
    	ResponseEntity rse = new ResponseEntity(paper2,HttpStatus.OK);
    	return rse;
    }

    /**
     * 删除导入试卷
     * @param paper_id
     * @return
     */
    @DeleteMapping(value = "/importPaper/{importPaper_id}")
    public ResponseEntity removePaper(@PathVariable String importPaper_id){
    	importPaperService.deleteImportPaper(importPaper_id);
    	ResponseEntity res = new ResponseEntity(importPaper_id,HttpStatus.OK);
		return res;
    }
}
